summaryrefslogtreecommitdiff
path: root/epan/exported_pdu.h
diff options
context:
space:
mode:
authorPascal Quantin <pascal.quantin@gmail.com>2014-04-18 16:43:36 +0200
committerAnders Broman <a.broman58@gmail.com>2014-04-18 20:15:04 +0000
commitad33357e627c02d4b4f9b78e75a78fbfebd1d12f (patch)
tree94c5f33c77f33e16ee7cd1020be4c27c2b986e10 /epan/exported_pdu.h
parentbe76ba5f0df80f2e0f44f2c8bad9ee2e7341a729 (diff)
downloadwireshark-ad33357e627c02d4b4f9b78e75a78fbfebd1d12f.tar.gz
Exported PDU: add support for more than 32 tags
Change-Id: Idc9f105164919827a8a81c88b5a56de4fa25df0b Reviewed-on: https://code.wireshark.org/review/1197 Reviewed-by: Anders Broman <a.broman58@gmail.com>
Diffstat (limited to 'epan/exported_pdu.h')
-rw-r--r--epan/exported_pdu.h30
1 files changed, 15 insertions, 15 deletions
diff --git a/epan/exported_pdu.h b/epan/exported_pdu.h
index 1bdc3ab534..8b10eca703 100644
--- a/epan/exported_pdu.h
+++ b/epan/exported_pdu.h
@@ -113,18 +113,17 @@ typedef struct _exp_pdu_data_t {
tvbuff_t *pdu_tvb;
} exp_pdu_data_t;
-#define EXP_PDU_TAG_IP_SRC_BIT 0x00000001
-#define EXP_PDU_TAG_IP_DST_BIT 0x00000002
-
-#define EXP_PDU_TAG_SRC_PORT_BIT 0x00000004
-#define EXP_PDU_TAG_DST_PORT_BIT 0x00000008
-
-#define EXP_PDU_TAG_SS7_OPC_BIT 0x00000020
-#define EXP_PDU_TAG_SS7_DPC_BIT 0x00000040
-
-#define EXP_PDU_TAG_ORIG_FNO_BIT 0x00000080
-
-#define EXP_PDU_TAG_DVBCI_EVT_BIT 0x00000100
+/* 1st byte of optional tags bitmap */
+#define EXP_PDU_TAG_IP_SRC_BIT 0x01
+#define EXP_PDU_TAG_IP_DST_BIT 0x02
+#define EXP_PDU_TAG_SRC_PORT_BIT 0x04
+#define EXP_PDU_TAG_DST_PORT_BIT 0x08
+#define EXP_PDU_TAG_SS7_OPC_BIT 0x20
+#define EXP_PDU_TAG_SS7_DPC_BIT 0x40
+#define EXP_PDU_TAG_ORIG_FNO_BIT 0x80
+
+/* 2nd byte of optional tags bitmap */
+#define EXP_PDU_TAG_DVBCI_EVT_BIT 0x01
#define EXP_PDU_TAG_IPV4_SRC_LEN 4
#define EXP_PDU_TAG_IPV4_DST_LEN 4
@@ -144,12 +143,13 @@ typedef struct _exp_pdu_data_t {
/**
* Allocates and fills the exp_pdu_data_t struct according to the wanted_exp_tags
* bit_fileld, if proto_name is != NULL, wtap_encap must be -1 or vice-versa
*
* The tags in the tag buffer SHOULD be added in numerical order.
*/
-WS_DLL_PUBLIC exp_pdu_data_t *load_export_pdu_tags(packet_info *pinfo,
- const char* proto_name, int wtap_encap, guint32 wanted_exp_tags);
+WS_DLL_PUBLIC exp_pdu_data_t *load_export_pdu_tags(packet_info *pinfo, const char* proto_name,
+ int wtap_encap, guint8 *wanted_exp_tags, guint16 wanted_exp_tags_len);
#endif /* EXPORTED_PDU_H */
@@ -144,12 +143,13 @@ typedef struct _exp_pdu_data_t {
/**
* Allocates and fills the exp_pdu_data_t struct according to the wanted_exp_tags
- * bit_fileld, if proto_name is != NULL, wtap_encap must be -1 or vice-versa
+ * bit field of wanted_exp_tags_len bytes length
+ * If proto_name is != NULL, wtap_encap must be -1 or vice-versa
*
* The tags in the tag buffer SHOULD be added in numerical order.